@@ -1,6 +1,6 @@
-linux-6.6.120-sparky-lts66 for Debian
+linux-6.6.122-sparky-lts66 for Debian
 ------------------------------------
 
 <Possible notes regarding this package - if none, delete this file.>
 
- -- pavroo <pavroo@onet.eu>  Tue, 13 Jan 2026 11:34:45 +0100
+ -- pavroo <pavroo@onet.eu>  Fri, 30 Jan 2026 17:37:14 +0100
